#
# spec file for package qatengine
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qatengine
Version:        0.6.18
Release:        150500.1.1
Summary:        Intel QuickAssist Technology (QAT) QATengine Library
License:        BSD-3-Clause
Group:          Hardware/Other
URL:            https://github.com/intel/QAT_Engine
Source:         https://github.com/intel/QAT_Engine/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc >= 4.8.5
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  qatlib-devel >= 21.08.0
BuildRequires:  zlib-devel >= 1.2.7
# This package can be built on all archs, but is useful only on enterprise-class intel.
ExclusiveArch:  x86_64

%description
Intel® QuickAssist Technology OpenSSL* Engine (QAT_Engine) supports
acceleration for both hardware as well as optimized software based
on vectorized instructions. This package contains an OpenSSL engine
module that utilises QAT.

%prep
%autosetup -n QAT_Engine-%{version}

%build
%{set_build_flags}
autoreconf -fiv
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license LICENSE*
%{_libdir}/engines-*/%{name}.so

%changelog
* Sat Jan 28 2023 dmueller@suse.com
- update to 0.6.18:
  * Fix address sanitizer issues
  * Fix issues with Babassl & Openssl3.0
  * Add QAT_HW SM4 CBC support
  * Refactor ECX provider code into single file
  * Fix QAT_HW AES-GCM bad mac record & memleak
  * Fix SHA3 memory leak
  * Fix sm4-cbc build error with system default OpenSSL
  * Symmetric performance Optimization & memleak fixes
  * Bug fix, README & v0.6.18 Version update
  * Please refer README (Software requirements section) for dependent
    libraries release version and other information.
* Sat Dec  3 2022 dmueller@suse.com
- update to v0.6.17:
  * Add security policy - c1a7a96
  * Add dependancy update tool file - 522c41d
  * Release v0.6.17 version update - c1a7a96
  * Enable QAT_SW RSA & ECDSA support for BoringSSL - 1035e82
  * Fix QAT_SW SM2 ECDSA Performance issue - f44a564
  * CPP check and Makefile Bug fixes - 98ccbe8
  * Fix buffer overflow issue with SHA3 and ECX - cab65f3
  * Update version and README for v0.6.16 - 1c95fd7
  * Split --with-qat_sw_install_dir into seperate configures - d5f5656
  * Add seperate err files for Boringssl - 1a09627
  * Fix QAT_HW & QAT_SW AES-GCM issue with s_server in provider - c775f5c
  * Fix issue with disable flags in provider - 2e00636
  * Fix coredump issue in provider with qat_sw gcm - 6703c13
  * Fix err files regeneration failure - 510f3dc
  * Add Provider Support for ChachaPoly and SM2 - a98e51d
  * Bug Fixes in testapp and with disable flags. - 0945535
  * QAT HW&SW Co-existence dynamic mechanism support. - 5baf5aa
  * Fix issue with SIGUSR1 during reload. - 00ea833
  * Refactor qat_hw instances based on Sym/Asym capabilities. - bb10128
  * Replace deprecated pthread_yield with sched_yield. - d514406
  * BoringSSL support for RSA and ECDSA. - 41c67c7
  * Fix s_server lseek forever issue with qatprovider. - cb3db21
  * Fix aes-cbc failure issue in testapp. - a530427
  * Fix glibc version test - 2461966
  * Fix issue with generator param and ECDSA verify. - c51fc17
  * Provider Support for DSA, DH, HKDF, PRF, SHA3 & aes-cbc - 7cc5eb9
  * Fix testapp issues and optimization - e7c2ba8
  * Optimize setup and clear async event notification - 573fe48
  * Fix Nginx worker process core dump in QAT_SW with pkill/killall -
    4eb4473
  * Add Cofactor to take optimized path in ECDH API - 9a23c7e
  * Fix double free issue with QAT_SW - 1a16708
  * Add thread mapping to specific QAT_HW instance - 5ee799a
  * OpenSSL 3.0 Provider Support - 38086fa
  * Update README and version to v0.6.12 - dca2957
  * Fixed worker process hung forever after nginx reload - bfe97aa
  * Remove OpenSSL 1.1.0 Support - da8682a
  * Add QAT_SW SM2 ECDH & SM3 support - 04a6af2
  * QAT_SW ECDSA SM2 sign and verify Support - d44ae7e
  * Disable SM3, Bug fixes, Readme & version update - d995046
* Thu Dec  2 2021 duwe@suse.com
- submit for jira feature SLE-20907
* Thu Nov 25 2021 duwe@suse.com
- copy from qatzip and transform into an OpenSSL engine spec
